--[[----------------------------------------------------------------------------

FtpUploadExportDialogSections.lua
Export dialog customization for Lightroom FTP uploader

--------------------------------------------------------------------------------

ADOBE SYSTEMS INCORPORATED
 Copyright 2007 Adobe Systems Incorporated
 All Rights Reserved.

NOTICE: Adobe permits you to use, modify, and distribute this file in accordance
with the terms of the Adobe license agreement accompanying it. If you have received
this file from a source other than Adobe, then your use, modification, or distribution
of it requires the prior written permission of Adobe.

------------------------------------------------------------------------------]]

-- Lightroom SDK
local LrView = import 'LrView'
local LrFtp = import 'LrFtp'

--============================================================================--

FtpUploadExportDialogSections = {}

-------------------------------------------------------------------------------

local function updateExportStatus( propertyTable )
	
	local message = nil
	
	repeat
		-- Use a repeat loop to allow easy way to "break" out.
		-- (It only goes through once.)
		
		if propertyTable.ftpPreset == nil then
			message = LOC "$$$/FtpUpload/ExportDialog/Messages/SelectPreset=Bitte wählen Sie FTP-Zugangsdaten aus."
			break
		end
		
		if ( propertyTable.path2prefix == nil )
			then
			message = LOC "$$$/FtpUpload/ExportDialog/Messages/EnterSubPath=Bitte wählen Sie die Art des Kunden."
			break
		end
		
		if (propertyTable.path == "" or propertyTable.path == nil)
			then
			message = LOC "$$$/FtpUpload/ExportDialog/Messages/EnterSubPath=Bitte geben Sie einen Benutzernamen an."
			break
		elseif string.find(propertyTable.path, "[&+/{}ßáàâéèêíìîóòôúùûñ]")
			then
			message = LOC "ACHTUNG! Ihr Benutzername enthält ungültige Zeichen."
			break
		end
		
		if (propertyTable.path2 == "" or propertyTable.path2 == nil)
			then
			message = LOC "$$$/FtpUpload/ExportDialog/Messages/EnterSubPath=Bitte geben Sie einen Albumnamen an."
			break
		elseif string.find(propertyTable.path2, "[&+/ßáàâéèêíìîóòôúùûñ]")
			then
			message = LOC "ACHTUNG! Ihr Albumname enthält ungültige Zeichen."
			break
		end
		
		local fullPath = propertyTable.ftpPreset.path or ""
		
		fullPath = LrFtp.appendFtpPaths( fullPath, propertyTable.path2prefix .. propertyTable.path )
		fullPath = LrFtp.appendFtpPaths( fullPath, propertyTable.path2 )
		propertyTable.fullPath = fullPath
		
	until true
	
	if message then
		propertyTable.message = message
		propertyTable.hasError = true
		propertyTable.hasNoError = false
		propertyTable.LR_cantExportBecause = message
	else
		propertyTable.message = nil
		propertyTable.hasError = false
		propertyTable.hasNoError = true
		propertyTable.LR_cantExportBecause = nil
	end
	
end

-------------------------------------------------------------------------------

function FtpUploadExportDialogSections.startDialog( propertyTable )
	
	propertyTable:addObserver( 'items', updateExportStatus )
	propertyTable:addObserver( 'path2prefix', updateExportStatus )
	propertyTable:addObserver( 'path', updateExportStatus )
	propertyTable:addObserver( 'path2', updateExportStatus )
	propertyTable:addObserver( 'putInSubfolder', updateExportStatus )
	propertyTable:addObserver( 'ftpPreset', updateExportStatus )
	updateExportStatus( propertyTable )
	
end

-------------------------------------------------------------------------------

function FtpUploadExportDialogSections.sectionsForBottomOfDialog( _, propertyTable )

	local f = LrView.osFactory()
	local bind = LrView.bind
	local share = LrView.share
	local LrFtp = import 'LrFtp'

	local result = {
	
		{
			title = LOC "$$$/FtpUpload/ExportDialog/FtpSettings=portraitbox-Einstellungen",
			
			synopsis = bind { key = 'fullPath', object = propertyTable },
			
			f:row {
				f:static_text {
					title = LOC "$$$/FtpUpload/ExportDialog/FTP-Zugangsdaten=FTP-Zugangsdaten:",
					alignment = 'right',
					width = share 'labelWidth'
				},
	
				LrFtp.makeFtpPresetPopup {
					factory = f,
					properties = propertyTable,
					valueBinding = 'ftpPreset',
					itemsBinding = 'items',
					fill_horizontal = 1,
				},
			},
		
		f:row {
			f:static_text {
				title = LOC "$$$/FtpUpload/ExportDialog/ArtdesKunden=Art des Kunden:",
				alignment = 'right',
				width = share 'labelWidth'
			},
			
			f:popup_menu {
				items = {-- the menu items and their values
					{ title = "Klassischer Kunde", value = '' },
					{ title = "Kindergarten / Schule", value = 'code-' },
				},
				value = bind 'path2prefix',
				validate = LrFtp.ftpPathValidator,
				size = 'small'
			},
		},
			
		f:row {
				
			f:static_text {
				title = LOC "$$$/FtpUpload/ExportDialog/FTP-Zugangsdaten=Kunde:",
				alignment = 'right',
				width = share 'labelWidth'
			},
				
			f:edit_field {
				value = bind 'path',
				validate = LrFtp.ftpPathValidator,
				truncation = 'middle',
				immediate = true,
				fill_horizontal = 1,
			},
				
		},
		
		f:row {
				
			f:static_text {
				title = LOC "$$$/FtpUpload/ExportDialog/FTP-Zugangsdaten=Fotoalbum:",
				alignment = 'right',
				width = share 'labelWidth'
			},
			
			f:edit_field {
				value = bind 'path2',
				validate = LrFtp.ftpPathValidator,
				truncation = 'middle',
				immediate = true,
				fill_horizontal = 1,
			},
				
			},
			
		},
	}
	
	return result
	
end
